# Generated by Django 4.2.19 on 2025-03-06 16:37

import django.core.validators
from django.db import migrations, models


def migrate_from_is_phone_mandatory(apps, schema_editor):
    """For continuity, move is_phone_mandatory to the new required_phone field, and set
       required_email=2 for the orders that were created so far."""

    GroupedOrder = apps.get_model("order", "GroupedOrder")
    for grouped_order in GroupedOrder.objects.all():
        grouped_order.required_email = 2
        grouped_order.required_phone = 2 if grouped_order.is_phone_mandatory else 1
        grouped_order.save()

class Migration(migrations.Migration):

    dependencies = [
        ("order", "0029_set_phone_mandatory_for_existing_orders"),
    ]

    operations = [
        migrations.AddField(
            model_name="groupedorder",
            name="required_email",
            field=models.IntegerField(
                verbose_name="Adresse email",
                blank=True,
                default=2,
                validators=[
                    django.core.validators.MaxValueValidator(2),
                    django.core.validators.MinValueValidator(0),
                ],
            ),
        ),
        migrations.AddField(
            model_name="groupedorder",
            name="required_phone",
            field=models.IntegerField(
                verbose_name="Numéro de téléphone",
                blank=True,
                default=2,
                validators=[
                    django.core.validators.MaxValueValidator(2),
                    django.core.validators.MinValueValidator(0),
                ],
            ),
        ),
        migrations.RunPython(migrate_from_is_phone_mandatory),
        migrations.RemoveField(
            model_name="groupedorder",
            name="is_phone_mandatory",
        ),
    ]
